@@ -6,6 +6,8 @@ describe "ImageProcessing::Vips" do
   before do
     @portrait  = fixture_image("portrait.jpg")
     @landscape = fixture_image("landscape.jpg")
+    @square = fixture_image("square.jpg")
+    @exif_portrait = fixture_image("exif_portrait.jpg")
   end
 
   it "applies vips operations" do
@@ -115,7 +117,7 @@ describe "ImageProcessing::Vips" do
 
   it "raises correct Vips::Error on unknown saver" do
     error = assert_raises(Vips::Error) { ImageProcessing::Vips.convert("foo").call(@portrait) }
-    assert_includes error.message, "No known saver"
+    assert_match /is not a known file format|No known saver for/, error.message
   end
 
   it "accepts :saver" do
@@ -295,7 +297,7 @@ describe "ImageProcessing::Vips" do
     it "produces correct image when enlarging" do
       @pipeline = ImageProcessing::Vips.source(@landscape)
       expected = fixture_image("pad-large.jpg")
-      assert_similar expected, @pipeline.resize_and_pad!(1000, 1000, background: [0, 255, 0])
+      assert_similar expected, @pipeline.resize_and_pad!(1000, 1000, background: [55, 126, 34])
     end
 
     it "accepts gravity" do
@@ -306,7 +308,7 @@ describe "ImageProcessing::Vips" do
 
     it "accepts thumbnail options" do
       pad  = @pipeline.resize_and_pad!(400, 400)
-      crop = @pipeline.resize_and_pad!(400, 400, crop: :centre)
+      crop = @pipeline.resize_and_pad!(400, 400, crop: :entropy)
       refute_similar pad, crop
     end
 
@@ -322,12 +324,83 @@ describe "ImageProcessing::Vips" do
     end
   end
 
+  describe "#resize_to_cover" do
+    before do
+      @portrait_pipeline = ImageProcessing::Vips.source(@portrait)
+      @landscape_pipeline = ImageProcessing::Vips.source(@landscape)
+      @square_pipeline = ImageProcessing::Vips.source(@square)
+      @exif_portrait_pipeline = ImageProcessing::Vips.source(@exif_portrait)
+    end
+
+    it "resizes the portrait image to fill out the given landscape dimensions" do
+      assert_dimensions [300, 400], @portrait_pipeline.resize_to_cover!(300, 200)
+    end
+
+    it "resizes the portrait image to fill out the given portrait dimensions" do
+      assert_dimensions [225, 300], @portrait_pipeline.resize_to_cover!(200, 300)
+    end
+
+    it "resizes the portrait image to fill out the given square dimensions" do
+      assert_dimensions [300, 400], @portrait_pipeline.resize_to_cover!(300, 300)
+    end
+
+    it "resizes the landscape image to fill out the given portrait dimensions" do
+      assert_dimensions [400, 300], @landscape_pipeline.resize_to_cover!(200, 300)
+    end
+
+    it "resizes the landscape image to fill out the given landscape dimensions" do
+      assert_dimensions [300, 225], @landscape_pipeline.resize_to_cover!(300, 200)
+    end
+
+    it "resizes the landscape image to fill out the given square dimensions" do
+      assert_dimensions [400, 300], @landscape_pipeline.resize_to_cover!(300, 300)
+    end
+
+    it "resizes the square image to fill out the given portrait dimensions" do
+      assert_dimensions [300, 300], @square_pipeline.resize_to_cover!(200, 300)
+    end
+
+    it "resizes the square image to fill out the given landscape dimensions" do
+      assert_dimensions [300, 300], @square_pipeline.resize_to_cover!(300, 200)
+    end
+
+    it "resizes the square image to fill out the given square dimensions" do
+      assert_dimensions [300, 300], @square_pipeline.resize_to_cover!(300, 300)
+    end
+
+    it "produces correct image" do
+      expected = fixture_image("cover.jpg")
+      assert_similar expected, @portrait_pipeline.resize_to_cover!(300, 200)
+    end
+
+    it "accepts thumbnail options except :crop" do
+      attention = @portrait_pipeline.resize_to_cover!(400, 400, crop: :attention)
+      centre    = @portrait_pipeline.resize_to_cover!(400, 400, crop: :centre)
+      assert_similar centre, attention
+    end
+
+    it "accepts sharpening options" do
+      sharpened = @portrait_pipeline.resize_to_cover!(400, 400, sharpen: ImageProcessing::Vips::Processor::SHARPEN_MASK)
+      normal   = @portrait_pipeline.resize_to_cover!(400, 400, sharpen: false)
+      assert sharpened.size > normal.size, "Expected sharpened thumbnail to have bigger filesize than not sharpened thumbnail"
+    end
+
+    it "sharpening uses integer precision" do
+      sharpened = @portrait_pipeline.resize_to_cover(400, 400).call(save: false)
+      assert_equal :uchar, sharpened.format
+    end
+
+    it "works correctly with EXIF orientation" do
+      assert_dimensions [300, 617], @exif_portrait_pipeline.resize_to_cover!(300, 200)
+    end
+  end
+
   describe "#rotate" do
     before do
       @pipeline = ImageProcessing::Vips.source(@portrait)
     end
 
-    it "rotates by muliples of 90" do
+    it "rotates by multiples of 90" do
       assert_dimensions [600, 800], @pipeline.rotate!(0)
       assert_dimensions [800, 600], @pipeline.rotate!(90)
       assert_dimensions [600, 800], @pipeline.rotate!(180)
